==> hermes-6.0.0.11.tar.gz: hermes-6.0.0.11/app/controllers/hermes/api/dmo/operations_controller.rb <==
# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class OperationsController < Hermes::Api::Dmo::ApplicationController

        VALID_OPERATORS = %w[
          $in
          $nin
          $ne
          $gt
          $gte
          $lt
          $lte
          $regex
        ].freeze

        ACCEPTABLE_PARAMS = %w[
          name
          code
          lessor_id
        ].freeze

        REGEX_PARAMS = %w[
          name
        ].freeze

        MUTATE_PARAMS = %i[
          name
          code
          lessor_id
        ].freeze
        
        def mutate_params
          MUTATE_PARAMS
        end 
        
        def set_instance
          @instance = nil
          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id).map(&:to_s)

          params[:name][:$regex]= /#{::Regexp.escape(params[:name][:$regex]).accent_to_regexp}/i if params[:name] && params[:name][:$regex]

          if params[:id]
            @instance = @model.where({
              id: params[:id],
              '$or': [
                {lessor_id: { '$in': lessor_ids}},
                {lessor_id: nil},
              ]
            }).first
          end
        end

        def is_admin
          (
            @user.auth_roles&.include?('superadministrateur') || 
            @user.roles&.include?('Administrator') || 
            @user.roles&.include?('SuperAdmin') || 
            @user.roles&.include?('Manager')
          )
        end

        def create
          if !is_admin && (!mutate_valid_params[:lessor_id] || !Hermes::Lessor.find_by(id: mutate_valid_params[:lessor_id]).readable_by?(@user))
            return render_json_error(:unprocessable_entity, :cannot_create_without_lessor_id)
          end
          super
        end

        def user_can_destroy?
          if is_admin || (
            @instance.lessor_id && 
            Hermes::Lessor.find_by(id: @instance.lessor_id).readable_by?(@user)
          )
            return true
          end
          false
        end

        def index
          acceptable_params *ACCEPTABLE_PARAMS
          regex_params *REGEX_PARAMS
          valid_operators *VALID_OPERATORS

          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id)
          aggregation = index_aggregation(no_acl: true).where({
            '$or': [
              {lessor_id: { '$in': lessor_ids}},
              {lessor_id: nil},
            ] 
          })
          
          paginate(
            aggregation,
            each_serializer: @serializer,
            **@options
          )
        end
      end
    end
  end
end

==> hermes-6.0.1.22.tar.gz: hermes-6.0.1.22/app/controllers/hermes/api/dmo/operations_controller.rb <==
# frozen_string_literal: true
# checker Api::Dmo::HermesController avant d'ajouter des méthodes
module Hermes
  module Api
    module Dmo
      class OperationsController < Hermes::Api::Dmo::ApplicationController

        class << self
          def mutate_params
            {
              name: {type: 'String'},
              code: {type: 'String'},
              lessor_id: {type: 'String'},
            }
          end 
      
          def acceptable_params
            {

            }.merge(self.mutate_params).merge(super)
          end 
      
          def valid_operators
            %w[$in $nin $ne $gt $gte $lt $lte $regex]
          end
      
          def regex_params
            {

            }
          end 
        end
        
        def set_instance
          @instance = nil
          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id).map(&:to_s)

          params[:name][:$regex]= /#{::Regexp.escape(params[:name][:$regex]).accent_to_regexp}/i if params[:name] && params[:name][:$regex]

          if params[:id]
            @instance = @model.where({
              id: params[:id],
              '$or': [
                {lessor_id: { '$in': lessor_ids}},
                {lessor_id: nil},
              ]
            }).first
          end
        end

        def is_admin
          (
            @user.auth_roles&.include?('superadministrateur') || 
            @user.roles&.include?('Administrator') || 
            @user.roles&.include?('SuperAdmin') || 
            @user.roles&.include?('Manager')
          )
        end

        def create
          if !is_admin && (!mutate_valid_params[:lessor_id] || !Hermes::Lessor.find_by(id: mutate_valid_params[:lessor_id]).readable_by?(@user))
            return render_json_error(:unprocessable_entity, :cannot_create_without_lessor_id)
          end
          super
        end

        def user_can_destroy?
          if is_admin || (
            @instance.lessor_id && 
            Hermes::Lessor.find_by(id: @instance.lessor_id).readable_by?(@user)
          )
            return true
          end
          false
        end

        def index
          acceptable_params *self.class.acceptable_params.keys
          valid_operators *self.class.valid_operators

          lessor_ids = Hermes::Lessor.readable_by(@user).pluck(:id)
          aggregation = index_aggregation(no_acl: true).where({
            '$or': [
              {lessor_id: { '$in': lessor_ids}},
              {lessor_id: nil},
            ] 
          })
          
          paginate(
            aggregation,
            each_serializer: @serializer,
            **@options
          )
        end
      end
    end
  end
end
